@@ -115,7 +115,7 @@ class Study(BaseLabeledMhdModel):
     public_release_date: None | datetime.datetime = None
     license: Annotated[
         None | HttpUrl,
-        Field(examples=["https://creativecommons.org/publicdomain/zero/1.0/"]),
+        Field(examples=[HttpUrl("https://creativecommons.org/publicdomain/zero/1.0/")]),
     ] = None
     grant_identifiers: Annotated[None | list[GrantId], Field()] = None
     dataset_url_list: Annotated[None | list[AnyUrl], Field()] = None
@@ -205,7 +205,7 @@ class Publication(BaseLabeledMhdModel):
             alias="type",
         ),
     ] = "publication"
-    title: Annotated[str, Field(min_length=5)]
+    title: Annotated[str, Field(min_length=10)]
     doi: Annotated[DOI, Field()]
     pub_med_id: Annotated[None | PubMedId, Field()] = None
     authors: Annotated[None | Authors, Field()] = None
